@@ -11,44 +11,42 @@
 
 #include <mpegfile.h>
 
-struct ChapterEntry {
-    QString title;
-    QString link;
-    QString image;
-    int start;
-};
+#include "chapter.h"
+#include "entry.h"
 
 class ChapterModel : public QAbstractListModel
 {
     Q_OBJECT
 
-    Q_PROPERTY(QString enclosureId READ enclosureId WRITE setEnclosureId NOTIFY enclosureIdChanged)
-    Q_PROPERTY(QString enclosurePath READ enclosurePath WRITE setEnclosurePath NOTIFY enclosurePathChanged)
+    Q_PROPERTY(Entry *entry READ entry WRITE setEntry NOTIFY entryChanged)
+    Q_PROPERTY(Chapter *currentChapter READ currentChapter NOTIFY currentChapterChanged)
 
 public:
     enum RoleNames {
-        Title = Qt::UserRole,
-        Link,
-        Image,
-        StartTime,
-        FormattedStartTime,
+        TitleRole = Qt::DisplayRole,
+        LinkRole = Qt::UserRole + 1,
+        ImageRole,
+        StartTimeRole,
+        FormattedStartTimeRole,
+        ChapterRole,
     };
+    Q_ENUM(RoleNames);
 
     explicit ChapterModel(QObject *parent = nullptr);
+    ~ChapterModel();
 
     QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
     QHash<int, QByteArray> roleNames() const override;
     int rowCount(const QModelIndex &parent) const override;
 
-    void setEnclosureId(QString newEnclosureId);
-    QString enclosureId() const;
+    void setEntry(Entry *entry);
+    Entry *entry() const;
 
-    void setEnclosurePath(const QString &enclosurePath);
-    QString enclosurePath() const;
+    Chapter *currentChapter() const;
 
 Q_SIGNALS:
-    void enclosureIdChanged();
-    void enclosurePathChanged();
+    void entryChanged();
+    void currentChapterChanged();
 
 private:
     void load();
@@ -56,8 +54,8 @@ private:
     void loadChaptersFromFile();
     void loadMPEGChapters(TagLib::MPEG::File &f);
 
-    QString m_enclosureId;
-    QVector<ChapterEntry> m_chapters;
+    Entry *m_entry = nullptr;
+    QVector<Chapter *> m_chapters;
     KFormat m_kformat;
-    QString m_enclosurePath;
+    int m_currentChapter = 0;
 };
